# Basic template with imports for isystem.connect
# (c) iSystem AG, 2009

from __future__ import print_function

try:
    input = raw_input  # to work in Python 2 and Python 3
except NameError:
    pass

import isystem.connect as ic
from isystem.connect import IConnectDebug

cmgr = ic.ConnectionMgr()
cmgr.connectMRU('')

ide = ic.CIDEController(cmgr) 

# To configure the S70FS01GS, we need to write to CR3NV registers of both lower and upper die of the flash.
# To do so, we need to issue a 4BAM (4 byte address mode) command, and a WE command before writing to registers. 
# Once we issue a WE command, both dies have WE bit latched, they are reset independently 
# lower CR3NV address  = 0x00000004
# upper CR3NV address  = 0x04000004
# data to write to CR3NV = 0x8

print ("S70FS01GS sector map configuarion script.")
print (ide.serviceCall("/IOPEN/HW.SoC.QSPI_Cmd", "DeviceName:Standard SPI SFDP, Operation:Load"))
print("Jedec ID:")
print (ide.serviceCall("/IOPEN/HW.SoC.QSPI_Cmd", "DeviceName:Standard SPI SFDP, Operation:Execute, CMD:0x9F, NumDummyClocks:0, NumBytesToRead:3, NrInstructionPins:1, NrAddressPins:0, NrDataPins:1"))
print("Enter 4BAM:")
print (ide.serviceCall("/IOPEN/HW.SoC.QSPI_Cmd", "DeviceName:Standard SPI SFDP, Operation:Execute, CMD:0xB7, NumDummyClocks:0, NumBytesToRead:0, NrInstructionPins:1, NrAddressPins:0, NrDataPins:0"))
print("WREN:")
print (ide.serviceCall("/IOPEN/HW.SoC.QSPI_Cmd", "DeviceName:Standard SPI SFDP, Operation:Execute, CMD:0x06, NumDummyClocks:0, NumBytesToRead:0, NrInstructionPins:1, NrAddressPins:0, NrDataPins:0"))

# -------------------------------------------------------------------------
# Configure the bottom 4 KB sectors with remainder 256 KB sectors. 
print ("Configuring bottom 4 KB sectors with remainder 256 KB sectors.")
print("WRAR 0x08 to upper CR3NV:")
print (ide.serviceCall("/IOPEN/HW.SoC.QSPI_Cmd", "DeviceName:Standard SPI SFDP, Operation:Execute, CMD:0x71, NumDummyClocks:0, NumBytesToRead:0, NrInstructionPins:1, NrAddressPins:1, NrDataPins:1, NumAddrBytes:4, Address:0x04000004, Data:08"))
# -------------------------------------------------------------------------

# -------------------------------------------------------------------------
# Configure the top 4 KB sectors with remainder 256 KB sectors.
# print ("Configuring top 4 KB sectors with remainder 256 KB sectors.")
# print("WRAR 0x08 to lower CR3NV:")
# print (ide.serviceCall("/IOPEN/HW.SoC.QSPI_Cmd", "DeviceName:Standard SPI SFDP, Operation:Execute, CMD:0x71, NumDummyClocks:0, NumBytesToRead:0, NrInstructionPins:1, NrAddressPins:1, NrDataPins:1, NumAddrBytes:4, Address:0x00000004, Data:08"))
# -------------------------------------------------------------------------

# -------------------------------------------------------------------------
# Configure the uniform 256 KB sectors.
# print ("Configuring uniform 256 KB sectors.")
# print("WRAR 0x08 to lower CR3NV:")
# print (ide.serviceCall("/IOPEN/HW.SoC.QSPI_Cmd", "DeviceName:Standard SPI SFDP, Operation:Execute, CMD:0x71, NumDummyClocks:0, NumBytesToRead:0, NrInstructionPins:1, NrAddressPins:1, NrDataPins:1, NumAddrBytes:4, Address:0x00000004, Data:08"))
# print("WRAR 0x08 to upper CR3NV:")
# print (ide.serviceCall("/IOPEN/HW.SoC.QSPI_Cmd", "DeviceName:Standard SPI SFDP, Operation:Execute, CMD:0x71, NumDummyClocks:0, NumBytesToRead:0, NrInstructionPins:1, NrAddressPins:1, NrDataPins:1, NumAddrBytes:4, Address:0x04000004, Data:08"))
# -------------------------------------------------------------------------

print (ide.serviceCall("/IOPEN/HW.SoC.QSPI_Cmd", "DeviceName:Standard SPI SFDP, Operation:Unload"))

input('Press Enter to quit...')

